"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var when_1 = require("../when");
var validators_1 = require("../validators");
var filters_1 = require("../filters");
function validatorFactory(rules) {
    return function (value) {
        return validators_1.validate([
            {
                value: value,
                rule: rules['scope-max-length'],
                validator: validators_1.maxLengthValidator,
                message: function (length) { return "Scope maximum length of " + length + " has been exceeded"; }
            },
            {
                value: value,
                rule: rules['scope-min-length'],
                validator: validators_1.minLengthValidator,
                message: function (length) { return "Scope minimum length of " + length + " has not been met"; }
            },
            {
                value: value,
                rule: rules['scope-empty'],
                validator: validators_1.emptyValidator,
                message: function () { return 'Scope cannot be empty'; }
            },
            {
                value: value,
                rule: rules['scope-case'],
                validator: validators_1.caseValidator,
                message: function (ruleValue, applicable) { return "Scope must " + (applicable == 'never' ? 'not ' : '') + "be in " + ruleValue; }
            }
        ]);
    };
}
exports.validatorFactory = validatorFactory;
function choicesFactory(rules) {
    var choices;
    if (rules['scope-enum']) {
        var _a = rules['scope-enum'], scopeEnum = _a[2];
        if (scopeEnum && scopeEnum.length > 0) {
            choices = scopeEnum;
        }
    }
    return choices;
}
exports.choicesFactory = choicesFactory;
function filterFactory(rules) {
    return function (value) { return filters_1.wordCaseFilter(value, rules['scope-case']); };
}
exports.filterFactory = filterFactory;
function scopeMaker(questions, rules) {
    var name = 'scope';
    var message = 'What is the scope of this change:\n';
    var when = when_1.whenFactory(rules['scope-enum'], rules['scope-empty']);
    var choices = choicesFactory(rules);
    var question;
    if (choices) {
        question = {
            name: name,
            message: message,
            when: when,
            validate: validatorFactory(rules),
            filter: filterFactory(rules),
            choices: choices,
            type: 'list'
        };
    }
    else {
        question = {
            name: name,
            message: message,
            when: when,
            validate: validatorFactory(rules),
            filter: filterFactory(rules),
            type: 'input'
        };
    }
    return tslib_1.__spreadArrays(questions, [question]);
}
exports.scopeMaker = scopeMaker;
